import { DynamoAttributeValue } from "@aws-cdk/aws-stepfunctions-tasks";
import { DynamoAttributeName } from "./attribute-name";
import { Placeholder } from "./placeholder";
export interface ExpressionAggregate {
    /**
     * Built expression that contains calculated placeholders.
     */
    readonly expression: string;
    /**
     * attribute values that used to substitute expression's placeholders by DynamoDB.
     */
    readonly expressionAttributeValues: {
        [key: string]: DynamoAttributeValue;
    };
    /**
     * attribute names that used to substitute expression's placeholders by DynamoDB.
     */
    readonly expressionAttributeNames?: {
        [key: string]: DynamoAttributeName;
    };
}
/**
 * An ExpressionBuilder instance builds the expression using calculated placeholders by referred attribute names and values.
 *
 * Each instance must correspond to the DynamoDB requests that using the expression.
 * If instances are used across different requests, the names and values that substitutes the placeholders may misplaced.
 */
export declare class ExpressionBuilder {
    private readonly valuesRefCounter;
    private readonly namesRefCounter;
    constructor();
    /**
     * Builds an expression and expression attribute values from template string.
     */
    expr(literals: TemplateStringsArray, ...placeholers: Placeholder[]): ExpressionAggregate;
}
