"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ExpressionBuilder = void 0;
const counter_1 = require("./counter");
const placeholder_1 = require("./placeholder");
/**
 * An ExpressionBuilder instance builds the expression using calculated placeholders by referred attribute names and values.
 *
 * Each instance must correspond to the DynamoDB requests that using the expression.
 * If instances are used across different requests, the names and values that substitutes the placeholders may misplaced.
 */
class ExpressionBuilder {
    constructor() {
        this.valuesRefCounter = counter_1.createRefCounter();
        this.namesRefCounter = counter_1.createRefCounter();
    }
    /**
     * Builds an expression and expression attribute values from template string.
     */
    expr(literals, ...placeholers) {
        let expression = "";
        const expressionAttributeValues = {};
        const expressionAttributeNames = {};
        placeholers.forEach((pv, idx) => {
            if (placeholder_1.isAttrName(pv)) {
                const { value } = this.namesRefCounter.next();
                const placeholder = `#${value}`;
                expression += literals[idx];
                expression += placeholder;
                expressionAttributeNames[placeholder] = pv;
            }
            else {
                const { value } = this.valuesRefCounter.next();
                const ref = `:v${value}`;
                expression += literals[idx];
                expression += ref;
                expressionAttributeValues[ref] = pv;
            }
        });
        expression += literals[literals.length - 1];
        return {
            expression,
            expressionAttributeValues,
            expressionAttributeNames: Object.keys(expressionAttributeNames).length === 0
                ? undefined
                : expressionAttributeNames,
        };
    }
}
exports.ExpressionBuilder = ExpressionBuilder;
